%define major 1
%define minor 5
%define fix 2

Name: zstd
Version: %{major}.%{minor}.%{fix}
Release: 1
License: BSD-3-Clause
Url: https://github.com/facebook/zstd
Summary: A fast lossless compression algorithm

Source0: https://github.com/facebook/zstd/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires: cmake >= 3.16.9

%description
Zstd, short for Zstandard, is a new lossless compression algorithm,
which provides both good compression ratio and speed for your standard 
compression needs. “Standard” translates into everyday situations which 
neither look for highest possible ratio (which LZMA and ZPAQ cover) nor 
extreme speeds (which LZ4 covers).

%package -n lib%{name}%{major}
Summary:        Zstd shared library

%description -n lib%{name}%{major}
Zstandard compression shared library.

%package -n lib%{name}-devel
Summary:        Header files for Zstd library
Requires:       lib%{name}%{major} = %{version}-%{release}

%description -n lib%{name}-devel
Header files for Zstd library.

%prep
%setup -q

cd build/cmake
mkdir cmake-build

%build

%define ldflags -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib
cd build/cmake/cmake-build

# NOTE: ZSTD_BUILD_STATIC is needed to build the zstd binary
cmake \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DZSTD_BUILD_SHARED=ON \
  -DZSTD_BUILD_STATIC=ON \
  ..
  
%make_build

%install
cd build/cmake/cmake-build

%make_install   

rm %{buildroot}/%{_libdir}/libzstd.a


%files
%defattr(-, qsys, *none)
%{_bindir}/zstd
%{_bindir}/zstdcat
%{_bindir}/unzstd
%{_bindir}/zstdgrep
%{_bindir}/zstdless
%{_bindir}/zstdmt
%{_mandir}/man1/zstd.1*
%{_mandir}/man1/zstdcat.1*
%{_mandir}/man1/unzstd.1*
%{_mandir}/man1/zstdgrep.1*
%{_mandir}/man1/zstdless.1*

%license LICENSE
%doc README.md


%files -n lib%{name}%{major}
%defattr(-, qsys, *none)
%{_libdir}/lib%{name}.so.*

%license LICENSE
%doc README.md

%files -n lib%{name}-devel
%defattr(-, qsys, *none)
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/cmake/zstd/
%{_libdir}/libzstd.so

%{_includedir}/zstd.h
%{_includedir}/zdict.h
%{_includedir}/zstd_errors.h


%changelog
* Fri Mar 25 2022 Kevin Adler <kadler@us.ibm.com> - 1.5.2
- Update to 1.5.2
- Remove internal/deprecated headers

* Fri Mar 25 2022 Kevin Adler <kadler@us.ibm.com> - 1.4.4
- Use CMake 3.16.9 to generate correct svr4 library instead of renaming manually

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 1.4.4
- Use generic paths for man and info pages to allow for compression

* Tue Apr 7 2020 - Naveen Ram <naveen.ram@ibm.com> - 1.4.4
- Initial package
